summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoOpenPane.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoOpenPane.h')
-rw-r--r--lib/kofficecore/KoOpenPane.h29
1 files changed, 15 insertions, 14 deletions
diff --git a/lib/kofficecore/KoOpenPane.h b/lib/kofficecore/KoOpenPane.h
index 20bd425d..818c6e81 100644
--- a/lib/kofficecore/KoOpenPane.h
+++ b/lib/kofficecore/KoOpenPane.h
@@ -26,7 +26,7 @@ class KConfig;
class KoTemplateGroup;
class KoOpenPanePrivate;
class KInstance;
-class QPixmap;
+class TQPixmap;
class KListViewItem;
class KoTemplatesPane;
class KoDetailsPaneBase;
@@ -34,19 +34,20 @@ class KoDetailsPaneBase;
class KoOpenPane : public KoOpenPaneBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
* @param parent the parent widget
* @param instance the KInstance to be used for KConfig data
* @param templateType the template-type (group) that should be selected on creation.
*/
- KoOpenPane(QWidget *parent, KInstance* instance, const QString& templateType = QString::null);
+ KoOpenPane(TQWidget *tqparent, KInstance* instance, const TQString& templateType = TQString());
virtual ~KoOpenPane();
- QListViewItem* addPane(const QString& title, const QString& icon, QWidget* widget, int sortWeight);
- QListViewItem* addPane(const QString& title, const QPixmap& icon, QWidget* widget, int sortWeight);
+ TQListViewItem* addPane(const TQString& title, const TQString& icon, TQWidget* widget, int sortWeight);
+ TQListViewItem* addPane(const TQString& title, const TQPixmap& icon, TQWidget* widget, int sortWeight);
/**
* If the application has a way to create a document not based on a template, but on user
@@ -54,26 +55,26 @@ class KoOpenPane : public KoOpenPaneBase
* @see KoDocument::createCustomDocumentWidget()
* @param widget the widget.
*/
- void setCustomDocumentWidget(QWidget *widget);
+ void setCustomDocumentWidget(TQWidget *widget);
protected slots:
void showOpenFileDialog();
- void selectionChanged(QListViewItem* item);
- void itemClicked(QListViewItem* item);
+ void selectionChanged(TQListViewItem* item);
+ void itemClicked(TQListViewItem* item);
/// Saves the splitter sizes for KoDetailsPaneBase based panes
- void saveSplitterSizes(KoDetailsPaneBase* sender, const QValueList<int>& sizes);
+ void saveSplitterSizes(KoDetailsPaneBase* sender, const TQValueList<int>& sizes);
signals:
- void openExistingFile(const QString&);
- void openTemplate(const QString&);
+ void openExistingFile(const TQString&);
+ void openTemplate(const TQString&);
/// Emitted when the always use template has changed
- void alwaysUseChanged(KoTemplatesPane* sender, const QString& alwaysUse);
+ void alwaysUseChanged(KoTemplatesPane* sender, const TQString& alwaysUse);
/// Emitted when one of the detail panes have changed it's splitter
- void splitterResized(KoDetailsPaneBase* sender, const QValueList<int>& sizes);
+ void splitterResized(KoDetailsPaneBase* sender, const TQValueList<int>& sizes);
protected:
void initRecentDocs();
@@ -81,7 +82,7 @@ class KoOpenPane : public KoOpenPaneBase
* Populate the list with all templates the user can choose.
* @param templateType the template-type (group) that should be selected on creation.
*/
- void initTemplates(const QString& templateType);
+ void initTemplates(const TQString& templateType);
private:
KoOpenPanePrivate* d;
@@ -34,19 +34,20 @@ class KoDetailsPaneBase;
/**
* Constructor
- * @param parent the parent widget
+ * @param tqparent the tqparent widget
* @param instance the KInstance to be used for KConfig data
* @param templateType the template-type (group) that should be selected on creation.